==> org.apache.felix.http.base-4.2.0-source-release.tar.gz: org.apache.felix.http.base-4.2.0/src/main/java/org/apache/felix/http/base/internal/runtime/dto/RegistryRuntime.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.felix.http.base.internal.runtime.dto;

import java.util.Collection;

import org.osgi.service.http.runtime.dto.PreprocessorDTO;
import org.osgi.service.http.runtime.dto.ServletContextDTO;

public final class RegistryRuntime
{
    private final Collection<ServletContextDTO> contextDTOs;
    private final FailedDTOHolder failedDTOHolder;
    private final Collection<PreprocessorDTO> preprocessorDTOs;

    public RegistryRuntime(final FailedDTOHolder failedDTOHolder,
            final Collection<ServletContextDTO> contextDTOs,
            final Collection<PreprocessorDTO> preprocessorDTOs)
    {
        this.failedDTOHolder = failedDTOHolder;
        this.contextDTOs = contextDTOs;
        this.preprocessorDTOs = preprocessorDTOs;
    }

    public FailedDTOHolder getFailedDTOHolder()
    {
        return this.failedDTOHolder;
    }

    public Collection<ServletContextDTO> getServletContextDTOs()
    {
        return this.contextDTOs;
    }

    public Collection<PreprocessorDTO> getPreprocessorDTOs()
    {
        return this.preprocessorDTOs;
    }
}

==> org.apache.felix.http.base-5.0.2-source-release.tar.gz: org.apache.felix.http.base-5.0.2/src/main/java/org/apache/felix/http/base/internal/runtime/dto/RegistryRuntime.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.felix.http.base.internal.runtime.dto;

import java.util.Collection;

import org.osgi.service.servlet.runtime.dto.PreprocessorDTO;
import org.osgi.service.servlet.runtime.dto.ServletContextDTO;

public final class RegistryRuntime
{
    private final Collection<ServletContextDTO> contextDTOs;
    private final FailedDTOHolder failedDTOHolder;
    private final Collection<PreprocessorDTO> preprocessorDTOs;

    public RegistryRuntime(final FailedDTOHolder failedDTOHolder,
            final Collection<ServletContextDTO> contextDTOs,
            final Collection<PreprocessorDTO> preprocessorDTOs)
    {
        this.failedDTOHolder = failedDTOHolder;
        this.contextDTOs = contextDTOs;
        this.preprocessorDTOs = preprocessorDTOs;
    }

    public FailedDTOHolder getFailedDTOHolder()
    {
        return this.failedDTOHolder;
    }

    public Collection<ServletContextDTO> getServletContextDTOs()
    {
        return this.contextDTOs;
    }

    public Collection<PreprocessorDTO> getPreprocessorDTOs()
    {
        return this.preprocessorDTOs;
    }
}
